@@ -27,7 +27,7 @@ update_pxweb_apis <- function(){
   api_remote_list <- get_api_list_remote(raw = TRUE)
   api_list$apis <- api_remote_list$apis
   write_api_list(api_list = api_list)
-  message("pxweb api catalogue updated.")
+  message("pxweb api catalogue updated (temporary).")
 }
 
 #' Check and compare differences between remote and local api catalogue
@@ -36,12 +36,12 @@ check_new_pxweb_apis <- function(){
   api_local_name <- names(get_api_list(raw = TRUE)$apis)
   api_remote_name <- try(names(get_api_list_remote(raw = TRUE)$apis), silent = TRUE)
   if(class(api_remote_name) == "try-error") return(NULL)
-    
+  
   remote_in_local <- api_remote_name %in% api_local_name
   if(!all(remote_in_local)){
     return(paste0("New PXWEB API(s):\n - ", 
-            paste(api_remote_name[!remote_in_local], collapse = "\n - "),
-            "\n\nUse update_pxweb_apis() to update the api catalogue."))
+                  paste(api_remote_name[!remote_in_local], collapse = "\n - "),
+                  "\n\nUse update_pxweb_apis() to update the api catalogue."))
   }
 }
 
@@ -55,13 +55,13 @@ check_new_pxweb_apis <- function(){
 get_github_api_urls <- function(type){
   if(type == "github_api") {
     return("https://api.github.com/repos/rOpenGov/pxweb/contents/inst/extdata/api.json?ref=master")
-#    warning("api_fix")
-#    return("https://api.github.com/repos/rOpenGov/pxweb/contents/inst/extdata/api.json?ref=api_fix")
+    #    warning("api_fix")
+    #    return("https://api.github.com/repos/rOpenGov/pxweb/contents/inst/extdata/api.json?ref=api_fix")
   }
   if(type == "github_raw"){
     return("https://raw.githubusercontent.com/rOpenGov/pxweb/master/inst/extdata/api.json")  
-#    warning("api_fix")
-#    return("https://raw.githubusercontent.com/rOpenGov/pxweb/api_fix/inst/extdata/api.json")
+    #    warning("api_fix")
+    #    return("https://raw.githubusercontent.com/rOpenGov/pxweb/api_fix/inst/extdata/api.json")
   }
   stop("No correct type")
 }
@@ -76,7 +76,7 @@ get_github_api_urls <- function(type){
 #' @return api_list object
 #' 
 get_api_list <- function(raw = FALSE){
-  api_file <- system.file("extdata/api.json", package = "pxweb")
+  api_file <- get_api_file_path()
   api_raw <- RJSONIO::fromJSON(api_file)
   if(raw) return(api_raw)
   api_list <- c(api_raw$apis, api_raw$local_apis)
@@ -110,12 +110,11 @@ get_api_list_remote <- function(raw = FALSE){
 #' 
 #' @param api_list api list in raw format to write to json file.
 write_api_list <- function(api_list){
-  dest <- system.file("extdata/api.json", package = "pxweb")
+  dest <- get_api_file_path()
   writeLines(RJSONIO::toJSON(api_list), con = dest)
 }
 
-
-#' Get index of which api has the name or teh alias
+#' Get index of which api has the name or the alias
 #'
 #' @param api_name pxweb api name or alias to lookup.
 #' @param api_list pxweb api list created with \code{get_api_list()}
@@ -132,3 +131,28 @@ get_api_index<- function(api_name, api_list){
   if(sum(in_list) == 0) stop("API do not exist in api catalogue.")
   which(in_list)[1]
 }
+
+
+
+#' The path to store paths to api.json
+#' @keywords internal 
+temp_api_file_path <- function(){
+  file.path(temp_api_folder_path(), "api.json")
+}
+
+#' The path to the folder to store paths to api.json
+#' @keywords internal 
+temp_api_folder_path <- function(){
+  file.path(tempdir(), "pxweb")
+}
+
+#' Refactorized function to get api_file path and copy if needed
+#' @keywords internal 
+get_api_file_path <- function(){
+  api_file <- temp_api_file_path()
+  if(!file.exists(api_file)){
+    dir.create(temp_api_folder_path(), recursive = TRUE)
+    file.copy(system.file("extdata/api.json", package = "pxweb"), api_file)
+  }
+  api_file
+}
